=========================
Oscar 1.0.1 release notes
=========================

This is Oscar 1.0.1, a bug fix release.

Bug fixes
=========

* `#1553`_: ``from oscar.apps.partner.models import *`` could lead to the
  wrong models being imported.

* `#1556`_: Dashboard order table headers shifted

* `#1557`_: Fixed an issue where Oscar wrongly used Django's ``is_safe_url``.
  Hence some redirects might not have worked as expected. This change
  unfortunately meant updating the notation of
  :meth:`oscar.core.utils.safe_referrer` and
  :meth:`oscar.core.utils.redirect_to_referrer` to accept the request instead
  of request.META.

* `#1577`_: The billing address was not being correctly passed through to the
  `place_order` method.

* `#1592`_: ``Product.min_child_price_[excl|incl]_tax`` were broken and
  failing loudly. They are not recommended any more, but to ensure
  backwards-compatibility, they have been fixed.

  .. _#1553: https://github.com/django-oscar/django-oscar/issues/1553
  .. _#1556: https://github.com/django-oscar/django-oscar/issues/1556
  .. _#1557: https://github.com/django-oscar/django-oscar/issues/1557
  .. _#1577: https://github.com/django-oscar/django-oscar/issues/1577
  .. _#1592: https://github.com/django-oscar/django-oscar/issues/1592

